@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.3.0 $
+### $Release: 0.4.0 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -19,7 +19,7 @@ import os, re
 from glob import glob
 from kook.utils import read_file, write_file
 
-release   = prop('release', '0.3.0')
+release   = prop('release', '0.4.0')
 package   = prop('package', 'Oktest')
 copyright = prop('copyright', "copyright(c) 2010 kuwata-lab.com all rights reserved")
 license   = "MIT License"
@@ -32,6 +32,21 @@ python = prop('python', 'python')
 def task_test(c):
     system(c%"$(python) test/oktest_test.py")
 
+@recipe
+def task_test_all(c):
+    "do test with python 2.5, 2.6, 2.7, 3.0, 3.1"
+    versions = [
+        ('2.5', '/opt/local/bin/python2.5'),
+        ('2.6', '/opt/local/bin/python2.6'),
+        ('2.7', '/opt/local/bin/python2.7'),
+        ('3.0', '/usr/local/python/3.0.1/bin/python'),
+        ('3.1', '/usr/local/python/3.1/bin/python'),
+    ]
+    for ver, bin in versions:
+        print("#")
+        print("# python " + ver)
+        print("#")
+        system(c%"PYTHON=$(bin) $(bin) test/oktest_test.py")
 
 @recipe
 def task_edit(c):
@@ -46,6 +61,12 @@ def task_edit(c):
     edit(filenames, by=replacer)
 
 
+@recipe
+def task_register(c):
+    """regsiter information into PyPI"""
+    system("python setup.py register")
+
+
 @recipe
 @spices('-a: create egg files for 2.4-2.7')
 def task_package(c, *args, **kwargs):
