@@ -1,5 +1,5 @@
 ###
-### $Release: 0.3.0 $
+### $Release: 0.4.0 $
 ### $Copyright: copyright(c) 2010 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -39,6 +39,8 @@ def do_test_with(desc, script, expected,  _pat=re.compile(r'0\.00[01]s')):
             echo("done.\n")
         elif _pat.sub('', output) == _pat.sub('', expected):
             echo("done.\n")
+        elif output == expected.replace('--- expected ', '--- expected').replace('+++ actual ', '+++ actual'):   # for Python 3.x
+            echo("done.\n")
         else:
             echo("FAILED.\n")
             if (isinstance(output, str) and isinstance(expected, str)):
@@ -280,6 +282,27 @@ expected = r"""
 """[1:]
 do_test_with(desc, script, expected)
 
+###
+desc = "in_delta()'"
+script = r"""
+from oktest import *
+class FooTest(object):
+    def test_in_delta(self):
+        ok (3.14159).in_delta(3.1415, 0.0001)
+class BarTest(object):
+    def test_in_delta(self):
+        ok (3.14159).in_delta(3.1415, 0.00001)
+run('FooTest', 'BarTest')
+"""[1:]
+expected = r"""
+* FooTest.test_in_delta ... [ok]
+* BarTest.test_in_delta ... [NG] 3.1415899999999999 < 3.1415100000000002 : failed.
+   _test_.py:7: ok (3.14159).in_delta(3.1415, 0.00001)
+"""[1:]
+if repr(3.14159) == '3.14159':    # for Python 3.x
+    expected = expected.replace('3.1415899999999999', '3.14159')
+do_test_with(desc, script, expected)
+
 ###
 desc = "op '.matches'"
 script = r"""
@@ -694,6 +717,8 @@ class FooTest(object):
        ok ('foo') == 'foo1'
     def test2(self):
        ok ("AAA\nBBB\nCCC\n") == "AAA\n888\nCCC"
+    def test3(self):   # bug: [ERROR] IndexError: list index out of range
+       ok ("") == "\n"
 run(FooTest)
 """[1:]
 expected = r"""
@@ -715,6 +740,14 @@ expected = r"""
 \ No newline at end of string
 +BBB
 +CCC
+* FooTest.test3 ... [NG] '' == '\n' : failed.
+   _test_.py:10: ok ("") == "\n"
+--- expected 
++++ actual 
+@@ -1,1 +1,1 @@
+-
++
+\ No newline at end of string
 """[1:]
 do_test_with(desc, script, expected)
 
